@@ -3,22 +3,26 @@
 // Purpose:     About dialog
 // Author:      Alex Thuering
 // Created:     6.11.2003
-// RCS-ID:      $Id: About.h,v 1.18 2008/11/01 10:09:25 ntalex Exp $
+// RCS-ID:      $Id: About.h,v 1.27 2014/01/02 06:45:19 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
 
 #include <wx/wx.h>
+#include <wx/html/htmlwin.h>
 #include "Version.h" //APP_VERSION
 
-const wxString APP_MAINT		= _T("Alex Thuering");
+const wxString APP_MAINT		= wxString(wxT("Alex Thüring"), wxConvUTF8);
 const wxString APP_NAME			= _T("DVDStyler");
 const wxString APP_LICENCE		= _T("GPL");
-const wxString APP_COPYRIGHT	= _T("(c) 2008 Alex Thuering");
-const wxString APP_WEBSITE		= _T("http://www.dvdstyler.de");
+const wxString APP_COPYRIGHT	= wxString(wxT("(c) 2003 - 2014 Alex Thüring"), wxConvUTF8);
+const wxString APP_WEBSITE		= _T("http://www.dvdstyler.org");
 
-class About: public wxDialog
-{
-  public:
-    About (wxWindow *parent);
+class About: public wxDialog {
+public:
+	About (wxWindow *parent);
+    
+private:
+	void OnLinkClicked(wxHtmlLinkEvent& event);
+	DECLARE_EVENT_TABLE()
 };
