@@ -3,7 +3,7 @@
 // Purpose:     DVD title properties dialog
 // Author:      Alex Thuering
 // Created:     31.01.2004
-// RCS-ID:      $Id: TitlePropDlg.h,v 1.10 2009/07/22 06:37:35 ntalex Exp $
+// RCS-ID:      $Id: TitlePropDlg.h,v 1.22 2013/12/29 21:41:13 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -13,34 +13,54 @@
 
 #include <wx/wx.h>
 #include <wxVillaLib/PropDlg.h>
+#include <wxVillaLib/Thumbnails.h>
 #include "DVD.h"
 #include "VobListBox.h"
 
 class TitlePropDlg: public wxPropDlg {
 public:
 	TitlePropDlg(wxWindow *parent, DVD* dvd, int tsi, int pgci, int vobi);
-	virtual ~TitlePropDlg() {}
-	
+	virtual ~TitlePropDlg();
+
+	/** Returns list of commands for choice */
+	static wxArrayString GetCommandList(DVD* dvd, int tsi);
+	/** Updates "Do not remultiplex"-checkbox */
+	void UpdateDoNotTranscodeCheck();
 private:
 	DVD* m_dvd;
-	Audio* m_audio;
-	Video* m_video;
+	int m_tsi;
+	int m_pgci;
+	PgcArray* m_pgcs;
 	Pgc* m_pgc;
 	Vob* m_vob;
 	int m_vobi;
+	wxArrayString* m_langCodes;
 	VobListBox* m_vobListBox;
 	wxCheckBox* m_doNotTranscodeCheckBox;
-	wxButton* m_addBt;
-	wxButton* m_delBt;
+	wxBitmapButton* m_addBt;
+	wxBitmapButton* m_delBt;
+	wxBitmapButton* m_propBt;
+	wxTextCtrl* m_chaptersCtrl;
+	wxButton* m_chaptersBt;
+	wxSpinCtrl* m_pause;
+	wxThumbnails* m_slideShowBox;
+	wxArrayString m_transitions;
+	wxChoice* m_audioFormat;
 	void CreatePropPanel(wxSizer* sizer);
+	void CreateVobGroup(wxSizer* sizer);
+	void CreateSlideshowGroup(wxSizer* sizer);
+	void CreateAudioGroup(wxSizer* sizer);
+	void CreateTitleGroup(wxSizer* sizer);
 	bool SetValues();
-	void CreateButtonPane(wxSizer* sizer, bool resetButton = false, bool dontShowCheckbox = false);
 	void OnSelectItem(wxCommandEvent& event);
 	void OnAddBt(wxCommandEvent& event);
 	void OnRemoveBt(wxCommandEvent& event);
-	void OnAV(wxCommandEvent& event);
+	void OnPropBt(wxCommandEvent& event);
+    void OnThumbDoubleClick(wxCommandEvent& event);
+	void OnChaptersBt(wxCommandEvent& event);
+	void OnChangeAudio(wxCommandEvent& event);
 	void OnDoNotTranscodeCheck(wxCommandEvent& event);
-	void UpdateDoNotTranscodeCheck();
+	void UpdateChaptersCtrl();
 	DECLARE_EVENT_TABLE()
 };
 
